import 'package:flutter/material.dart';
import 'package:xinlake_text/validator.dart' as validator;

class ValidatorDemo extends StatefulWidget {
  const ValidatorDemo({Key? key}) : super(key: key);

  @override
  State<ValidatorDemo> createState() => _ValidatorState();
}

class _ValidatorState extends State<ValidatorDemo> {
  static const String _invalidInput = "Invalid input";
  static const InputDecoration _decoration = InputDecoration(
    contentPadding: EdgeInsets.only(top: 8, bottom: 4),
  );

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      padding: const EdgeInsets.all(10),
      child: Column(
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Length 4 ~ 8")),
                  validator: (value) {
                    return (value != null && validator.isLength(value, 4, 8))
                        ? null
                        : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Letters (a~z, A~Z)")),
                  validator: (value) {
                    return (value != null && validator.isAlpha(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Numbers")),
                  validator: (value) {
                    return (value != null && validator.isNumeric(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Letters, Numbers")),
                  validator: (value) {
                    return (value != null && validator.isAlphanumeric(value))
                        ? null
                        : _invalidInput;
                  },
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("ASCII")),
                  validator: (value) {
                    return (value != null && validator.isAscii(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Multibyte")),
                  validator: (value) {
                    return (value != null && validator.isMultibyte(value)) ? null : _invalidInput;
                  },
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Hexadecimal")),
                  validator: (value) {
                    return (value != null && validator.isHexadecimal(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Hex color")),
                  validator: (value) {
                    return (value != null && validator.isHexColor(value)) ? null : _invalidInput;
                  },
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("IP")),
                  validator: (value) {
                    return (value != null && validator.isIP(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Port number")),
                  validator: (value) {
                    return (value != null && validator.isPortNumber(value)) ? null : _invalidInput;
                  },
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("FQDN")),
                  validator: (value) {
                    return (value != null && validator.isFQDN(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("URL")),
                  validator: (value) {
                    return (value != null && validator.isURL(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Email")),
                  validator: (value) {
                    return (value != null && validator.isEmail(value)) ? null : _invalidInput;
                  },
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Base64")),
                  validator: (value) {
                    return (value != null && validator.isBase64(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("UUID")),
                  validator: (value) {
                    return (value != null && validator.isUUID(value)) ? null : _invalidInput;
                  },
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Credit card")),
                  validator: (value) {
                    return (value != null && validator.isCreditCard(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("ISBN")),
                  validator: (value) {
                    return (value != null && validator.isISBN(value)) ? null : _invalidInput;
                  },
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Postal code")),
                  validator: (value) {
                    return (value != null && validator.isPostalCode(value, "CN"))
                        ? null
                        : _invalidInput;
                  },
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }
}
